Method: TZInfo::Timezone#now
- Defined in:
- lib/tzinfo/timezone.rb
#now ⇒ TimeWithOffset
Returns the current local time in the time zone.
992 993 994 |
# File 'lib/tzinfo/timezone.rb', line 992 def now to_local(Time.now) end |
Returns the current local time in the time zone.
992 993 994 |
# File 'lib/tzinfo/timezone.rb', line 992 def now to_local(Time.now) end |